% Compute beta equivalent to a given GRR 
%
% Input:
% f_vec - risk allele frequencies
% GRR_marginal - genetic relative risk for each SNP
% mu - disease prevalence in population
% SNP_TYPE - (optional) diploid (default) or binary 
%
% Output:
% beta - effect size on liability scale
% beta_vec - individual effect sizes on liability scale
% 
function [beta  beta_vec beta_binary] = ...
    genetic_relative_risk_to_beta(f_vec, GRR_marginal, mu, SNP_TYPE)

if(~exist('SNP_TYPE', 'var') || isempty(SNP_TYPE))
    SNP_TYPE = 'diploid';
end

[~,  h_liab_vec] = ...
    genetic_relative_risk_to_variance_explained(f_vec, GRR_marginal, mu, SNP_TYPE);

beta_vec = heritability_to_beta(h_liab_vec, f_vec, SNP_TYPE); % 'diploid'); 
beta_vec = beta_vec .* ((-1).^(GRR_marginal < 1)); % take sign
beta = sum(beta_vec); % additive model 

if(nargout > 2)
    beta_binary = fminbnd(@(x) abs(internal_beta_to_grr_binary(x, f_vec, mu, SNP_TYPE) - GRR_marginal), 0, 10);  % NEW! Also run binary: 
end

function grr_binary = internal_beta_to_grr_binary(beta, f_vec, mu, SNP_TYPE)
    [~, grr_binary] = beta_to_genetic_relative_risk(beta, f_vec, mu, SNP_TYPE);




