% Example of simulating a population with genotypes, IBD-blocks and phenotypes
% and estimating narrow-sense heritability for this population
plot_flag=0; num_bins = 100; % for plotting

%%%%%%%%%%%%% Set population demographic parameters (similar but higher IBD compared to paper's example) %%%%%%%
num_founders = 25;  % determines average IBD sharing
num_generations = 5;
num_individuals = 1000;
%f_vec = mat2vec(repmat([0.15 0.31 0.21 0.21 0.5 0.17 0.2 0.13 0.31 0.41 0.2 0.42 0.2 ...
%    0.17 0.15 0.15 0.4 0.5 0.2 0.2 0.22 0.2 0.17 0.2 0.11], 4, 1)); % Take a range of different allele frequencies. 100 SNPs
f_vec=mat2vec(repmat(0.5,500,1));

%%%%%%%%%%%%% Set LP model parameters from the paper's example %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
trait_type = 'quantitative';
num_pathways = 1; % Number of pathways in LP model. Make very non-linear !!! 
h_pathway = 0.5; % take very high heritability 
h_shared_env = 0; % 0.5 * (1-h_pathway);
f_vec = f_vec(1: end - mod(length(f_vec), num_pathways) ); % make all pathways with same # of SNPS
num_snps = length(f_vec); num_causal_snps = num_snps/2;
beta_vec = ones(num_snps,1); beta_vec(1:num_snps/2) = 0; % only first half of genotypes contribute to phenotype


%%%%% NEW: Parameters from Julie Douglas - something isn't working!!! %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % % num_founders=28
% % % num_generations=23
% % % num_individuals=1000
% % % f_vec=mat2vec(repmat([0.50],2000,1))
% % %
% % % trait_type='quantitative'
% % % num_pathways=1
% % % h_pathway=0.5
% % % h_shared_env=0
% % %
% % % num_snps = length(f_vec); num_causal_snps = num_snps/2;
% % % beta_vec = ones(num_snps,1); beta_vec(1:num_snps/2) = 0;
%%%%% END NEW: Parameters from Julie Douglas - something isn't working!!! %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


run_time = cputime; 
IBD_mean = 1/num_founders; % average IBD sharing 
[~, ~, ~, ~, ~, h_all_true] = ...
    compute_k_of_N_gaussian_statistics(0, 1, h_pathway, h_shared_env, [], ...
    'MAX', [], num_pathways, 10, 'numeric', 0, {'ACE'}); % Compute h_all (narrow sense heritability) for quantitative trait


%%%%%%%%%% Compute phenotype correlation analytically %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
IBD_vec = (0:num_bins) ./ num_bins;
if(~exist('rho_R_analytic', 'var') || isempty(rho_R_analytic))
    
    for i=1:length(IBD_vec)
        run_IBD_i = i 
        [~, tmp_qtl_R, same_inds_prob] = ...
            qtl_familial_correlations_internal(num_pathways, num_pathways, IBD_vec(i), ...
            'MAX', [], h_pathway, h_shared_env, 'numeric', []);
        rho_R_analytic(i) = tmp_qtl_R;
        same_max_liability_inds_analytic(i) = same_inds_prob; 
    end
end

if(~exist('rho_R_empirical', 'var') || isempty(rho_R_empirical))
    simulation_iters = 100000; 
    for i=1:length(IBD_vec)
        run_IBD_simulation_i = i 
        [~, tmp_qtl_R, same_inds_prob] = ...
            qtl_familial_correlations_internal(num_pathways, num_pathways, IBD_vec(i), ...
            'MAX', [], h_pathway, h_shared_env, 'simulation', simulation_iters);
        rho_R_empirical(i) = tmp_qtl_R;
        same_max_liability_inds_empirical(i) = same_inds_prob; 
    end
end
    

figure; hold on; plot(IBD_vec, rho_R_analytic); 
plot(IBD_vec, rho_R_empirical, '.');
plot(IBD_vec, same_max_liability_inds_analytic, 'r'); 
plot(IBD_vec, same_max_liability_inds_empirical, 'r.'); 
xlabel('IBD'); legend({'\rho(IBD)-analytic', '\rho(IBD)-empir.', 'P(Z=Z_R)-analytic', 'P(Z=Z_R)-empir.'}, 2); 



%%%%%%%%%%%%% Simulate SNPs and estimate heritability. Repeat many iterations %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
iters=100; h_all_estimated = zeros(iters, 1);
true_IBD_mat=[]; input_founder_identities = []; input_poiss_points = []; input_SNP_founder_identity_mat = [];
all_iters_phenotype_corr_by_IBD_vec = []; % initilize empty struct for collecting all simulation results
all_iters_genotype_corr_by_IBD_vec = []; 
for i=1:iters
    if(mod(i,10)==0)
        run_iter = i
    end
    [true_IBD_mat, ~, SNP_mat, ...  % Simulate IBD matrix and many SNP matrices
        founder_SNP_mat, input_SNP_founder_identity_mat, input_founder_identities, input_poiss_points] = ...
        simulate_IBD_blocks_sharing(num_founders, num_generations, num_individuals, f_vec, ...
        true_IBD_mat, input_founder_identities, input_poiss_points, input_SNP_founder_identity_mat);
    
%     % Normalize SNPs. Why? 
% %     for j=1:num_snps
% %         SNP_mat(j,:) = (SNP_mat(j,:) - mean(SNP_mat(j,:))) ./ std(SNP_mat(j,:));
% %     end
    
    SNP_corr_mat = corr(SNP_mat);
    true_IBD_mat = true_IBD_mat - diag(diag(true_IBD_mat));
    SNP_corr_mat = SNP_corr_mat - diag(diag(SNP_corr_mat));
    pairwise_genotype_corr_vec = squareform(SNP_corr_mat);
    
    [high_I high_J] = find(SNP_corr_mat > 0.95);  % take pairs with very high genotypic correlation 
    
    % Compute genotype correlations
    pairwise_IBD_vec = squareform(true_IBD_mat); 
    genotype_corr_by_IBD_vec.IBD_bins = (0:num_bins) ./ num_bins;
    genotype_corr_by_IBD_vec.corr_mean = zeros(num_bins+1,1);
    genotype_corr_by_IBD_vec.corr_std = zeros(num_bins+1,1);
    genotype_corr_by_IBD_vec.corr_counts = zeros(num_bins+1,1);
    cur_bins_vec = 1:max(floor(pairwise_IBD_vec*num_bins)+1);
    genotype_corr_by_IBD_vec.corr_mean(cur_bins_vec) = ...
        accumarray(floor(pairwise_IBD_vec'*num_bins)+1, pairwise_genotype_corr_vec', [], @mean);
    genotype_corr_by_IBD_vec.corr_std(cur_bins_vec) = ...
        accumarray(floor(pairwise_IBD_vec'*num_bins)+1, pairwise_genotype_corr_vec', [], @std);
    genotype_corr_by_IBD_vec.corr_counts(cur_bins_vec) = ...
        accumarray(floor(pairwise_IBD_vec'*num_bins)+1, pairwise_genotype_corr_vec', [], @length);
    
    
    
    
% % %     beta_IBD_snps = polyfit(squareform(true_IBD_mat), ...
% % %         squareform(SNP_corr_mat), 1); % local linear regression
% % %     xxx = squareform(true_IBD_mat); yyy = squareform(SNP_corr_mat);
% % %     [xxx xxx_perm] = sort(xxx); yyy = yyy(xxx_perm);
%     figure; plot(xxx, smooth(yyy, 100), '.')
%     hold on; plot(IBD_vec, IBD_vec .* beta_IBD_snps(1) + beta_IBD_snps(2), 'r', 'linewidth', 3);
%     title(['y = ' num2str(beta_IBD_snps(1),3) ' * x + ' num2str(beta_IBD_snps(2),3)]);
    



    [LP_phenotype_vec LP_max_pathway_vec] = simulate_LP_phenotypes(SNP_mat, f_vec, num_pathways, h_pathway, h_shared_env, trait_type); % Simulate phenotype. We also include shared environment component which can increase correlation)
    [h_all_estimated(i) phenotype_corr_by_IBD_vec pairwise_phenotype_corr_mat] = estimate_heritability_by_local_regression(true_IBD_mat, LP_phenotype_vec, num_bins, plot_flag); % estimate heritability
%     pairwise_phenotype_corr_mat(sub2ind(size(pairwise_phenotype_corr_mat), high_I, high_J));

    pairwise_phenotype_max_pathway_mat = (( repmat(LP_max_pathway_vec', num_individuals, 1) - ...
        repmat(LP_max_pathway_vec, 1, num_individuals) ) == 0); % matrix saying for each two individuals if they share the liability 
    pairwise_phenotype_max_pathway_mat = pairwise_phenotype_max_pathway_mat - diag(diag(pairwise_phenotype_max_pathway_mat)); 
    pairwise_phenotype_max_pathway_vec = squareform(pairwise_phenotype_max_pathway_mat); 
    phenotype_corr_by_IBD_vec.max_liability_prob = zeros(num_bins+1,1);
    phenotype_corr_by_IBD_vec.max_liability_prob(cur_bins_vec) = ...
        accumarray(floor(pairwise_IBD_vec'*num_bins)+1, pairwise_phenotype_max_pathway_vec', [], @mean);
    
    
    update_all_iters_phenotype_corr_by_IBD_vec; % update counts for all iterations
end

if(~isempty(high_I))
    figure; plot(SNP_corr_mat(sub2ind(size(SNP_corr_mat), high_I, high_J)), ...
        pairwise_phenotype_corr_mat(sub2ind(size(pairwise_phenotype_corr_mat), high_I, high_J)), '.');
    xlabel('Top genotype correlation'); ylabel('Top phenotype correlation');
    title(['Top: Mean: \rho(gen.)=' num2str( mean( SNP_corr_mat(sub2ind(size(SNP_corr_mat), high_I, high_J)) ) ) ', \rho(phen.)=' ...
        num2str(mean( pairwise_phenotype_corr_mat(sub2ind(size(pairwise_phenotype_corr_mat), high_I, high_J)) )) ...
        ' V(phen.)=' num2str(var( pairwise_phenotype_corr_mat(sub2ind(size(pairwise_phenotype_corr_mat), high_I, high_J)) )) ]);
end

if(~isempty(all_iters_genotype_corr_by_IBD_vec.top_values))
    figure; plot(all_iters_genotype_corr_by_IBD_vec.top_values, all_iters_phenotype_corr_by_IBD_vec.top_values, '.');
    xlabel('Top genotype correlation'); ylabel('Top phenotype correlation');
    title(['Top: Mean: $\rho(gen.)=' num2str( mean( all_iters_genotype_corr_by_IBD_vec.top_values ) ) ', \rho(phen.)=' ...
        num2str(mean( all_iters_phenotype_corr_by_IBD_vec.top_values )) ...
        ' V(phen.)=' num2str(var( all_iters_phenotype_corr_by_IBD_vec.top_values )) ...
        '. Pr(Z_i=Z_j)=' num2str( mean( all_iters_phenotype_corr_by_IBD_vec.top_max_inds_equal  ) ) '$' ], 'interpreter', 'latex');
end



%%%%%%%% Plot results: mean and st.d. of estimated heritability %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure; boxplot(h_all_estimated);
hold on; plot(1, h_all_true, 'k*');
ylabel('Estimated narrow-sense heritability');
title(['Estimated h^2 by local regression in ' num2str(iters) ' simulations']);
legend('true h_{all}^2');


%%%%%%%% Plot average regression line (similar to Figure 2 in pnas paper) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% First average over all iterations
all_iters_phenotype_corr_by_IBD_vec.corr_mean = all_iters_phenotype_corr_by_IBD_vec.corr_mean ./ ...
    all_iters_phenotype_corr_by_IBD_vec.corr_counts;
all_iters_phenotype_corr_by_IBD_vec.corr_std = ...
    sqrt( (all_iters_phenotype_corr_by_IBD_vec.corr_std - all_iters_phenotype_corr_by_IBD_vec.corr_mean.^2) ./ ...
    all_iters_phenotype_corr_by_IBD_vec.corr_counts ) ./ sqrt(all_iters_phenotype_corr_by_IBD_vec.corr_counts);
all_iters_phenotype_corr_by_IBD_vec.max_liability_prob = all_iters_phenotype_corr_by_IBD_vec.max_liability_prob ./ ...
    all_iters_phenotype_corr_by_IBD_vec.corr_counts;


% f_range = find((IBD_vec < 2.*IBD_mean) & (IBD_vec > 0));
f_range = find(IBD_vec <= 2.*IBD_mean); % 
f_range = intersect(f_range, find(~isnan(all_iters_phenotype_corr_by_IBD_vec.corr_mean)));
beta_linear_near_IBD_all_iters = polyfit(all_iters_phenotype_corr_by_IBD_vec.IBD_bins(f_range), ...
    all_iters_phenotype_corr_by_IBD_vec.corr_mean(f_range)', 1); % local linear regression
h_all_iters = beta_linear_near_IBD_all_iters(1)*(1-IBD_mean) % compute heritability estimator. Multiply by 1-IBD_mean (NOT SQUARE!!)

%f_range = 1:3; 
beta_near_IBD_analytic = polyfit(IBD_vec(f_range) .* (1-IBD_mean) + IBD_mean', ...
    rho_R_analytic(f_range), 1); % local linear regression
h_near_IBD_analytic = beta_near_IBD_analytic(1)*(1-IBD_mean) % compute heritability estimator. Multiply by 1-IBD_mean (NOT SQUARE!!)




figure; hold on;
x_vec = linspace(0, 1, num_bins); % bins for IBD
plot_beta = h_all_iters / (1-IBD_mean); % median(h_all_estimated) / (1-IBD_mean); % Compute median beta
plot_y0 = -plot_beta .* IBD_mean; % make sure regression line passes at (k0, 0)

% Normalize slope and multiply by constant to get an estimator for heritability
plot_mean_h_slope = median(h_all_estimated); % plot_beta*(1-IBD_mean)^2;
[~, plot_beta_std] = median_mad(h_all_estimated); % plot_beta_std = plot_beta_std / (1-IBD_mean);  % compute MAD robust std for beta

populated_bins = find(all_iters_phenotype_corr_by_IBD_vec.corr_counts >= 1000);
errorbar(all_iters_phenotype_corr_by_IBD_vec.IBD_bins(populated_bins), all_iters_phenotype_corr_by_IBD_vec.corr_mean(populated_bins), ...
    all_iters_phenotype_corr_by_IBD_vec.corr_std(populated_bins), ...
    'b', 'linewidth', 2); % plot averages of phenotypic correlations vs. IBD sharing
plot(IBD_vec .* (1-IBD_mean) + IBD_mean, rho_R_analytic, 'k', 'linewidth', 3);
plot(x_vec, plot_beta .* x_vec + plot_y0, 'r', 'linewidth', 2); % plot mean regression line



 % Fit a global slope 



xlabel('IBD sharing'); ylabel('\rho(IBD)');
legend('\rho empirical', '\rho theoretical', 'slope at k_0', 2); legend boxoff;
y_lim = get(gca, 'ylim');
line([IBD_mean IBD_mean], [y_lim(1)  0], ...
    'color', 'k', 'linestyle', '--');
line([0 IBD_mean], [0 0], ...
    'color', 'k', 'linestyle', '--');
text(IBD_mean, y_lim(1)*1.1, 'k_0', 'fontsize', 14);
xlim([0,1]);
slope_str = ['$h_{all}^2=' num2str(h_all_true,3) '$;  $h_{slope(mean-IBD)}^2 =' num2str(h_all_iters,3) ...  % plot_mean_h_slope
    ' \pm ' num2str(plot_beta_std/sqrt(iters),3) ', ( \sigma=' num2str(plot_beta_std,3)  ')$'];
text(min(0.6, IBD_mean*2), IBD_mean*0, slope_str, 'fontweight', 'bold', 'Interpreter','latex');








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Plot genotypic correlations 
% First average over all iterations
all_iters_genotype_corr_by_IBD_vec.corr_mean = all_iters_genotype_corr_by_IBD_vec.corr_mean ./ ...
    all_iters_genotype_corr_by_IBD_vec.corr_counts;
all_iters_genotype_corr_by_IBD_vec.corr_std = ...
    sqrt( (all_iters_genotype_corr_by_IBD_vec.corr_std - all_iters_genotype_corr_by_IBD_vec.corr_mean.^2) ./ ...
    all_iters_genotype_corr_by_IBD_vec.corr_counts ) ./ sqrt(all_iters_genotype_corr_by_IBD_vec.corr_counts);


figure; hold on;
x_vec = linspace(0, 1, num_bins); % bins for IBD
plot_beta = h_all_iters / (1-IBD_mean); % median(h_all_estimated) / (1-IBD_mean); % Compute median beta
plot_y0 = -plot_beta .* IBD_mean; % make sure regression line passes at (k0, 0)

% Normalize slope and multiply by constant to get an estimator for heritability
plot_mean_h_slope = median(h_all_estimated); % plot_beta*(1-IBD_mean)^2;
[~, plot_beta_std] = median_mad(h_all_estimated); % plot_beta_std = plot_beta_std / (1-IBD_mean);  % compute MAD robust std for beta

populated_bins = find(all_iters_genotype_corr_by_IBD_vec.corr_counts >= 1000);
errorbar(all_iters_genotype_corr_by_IBD_vec.IBD_bins(populated_bins), all_iters_genotype_corr_by_IBD_vec.corr_mean(populated_bins), ...
    all_iters_genotype_corr_by_IBD_vec.corr_std(populated_bins), ...
    'b', 'linewidth', 2); % plot averages of phenotypic correlations vs. IBD sharing
plot(IBD_vec, (IBD_vec - IBD_mean) ./ (1-IBD_mean), 'r', 'linewidth', 2); 
legend('data', 'analytic'); 
xlabel('IBD sharing'); ylabel('\rho(genotypes)');

% plot(IBD_vec .* (1-IBD_mean) + IBD_mean, rho_R_analytic, 'k', 'linewidth', 3); % 
% plot(x_vec, plot_beta .* x_vec + plot_y0, 'r', 'linewidth', 2); % plot mean regression line


figure; hold on; plot(all_iters_genotype_corr_by_IBD_vec.corr_mean(populated_bins), ...
    all_iters_phenotype_corr_by_IBD_vec.corr_mean(populated_bins), 'linewidth', 2); % plot phenotype correlation vs. genotype correlation
plot(IBD_vec, rho_R_analytic, 'k', 'linewidth', 3);

xlabel('\rho(genotypes)'); ylabel('\rho(phenotype)'); 
legend('\rho empirical', '\rho theoretical', 2); legend boxoff;

figure; hold on; plot(all_iters_phenotype_corr_by_IBD_vec.IBD_bins, ...
    all_iters_phenotype_corr_by_IBD_vec.max_liability_prob, '.'); 
xlabel('IBD'); ylabel('Prob.(U_1=U_2)'); 


figure; hold on; plot(all_iters_genotype_corr_by_IBD_vec.corr_mean, ...
    all_iters_phenotype_corr_by_IBD_vec.max_liability_prob, '.'); 

run_time = cputime - run_time 
